<?php
/**
 * Custom template tags for this theme
 *
 * Eventually, some of the functionality here could be replaced by core features.
 *
 * @package nesiapress
 */

if ( ! function_exists( 'nesiapress_posted_on' ) ) {
	/**
	 * Prints HTML with meta information for the current post-date/time.
	 *
	 * @since 1.0.0
	 *
	 * @return void
	 */
	function nesiapress_posted_on() {
		$time_string = '<time class="entry-date published updated" datetime="%1$s">%2$s</time>';

		$time_string = sprintf(
			$time_string,
			esc_attr( get_the_date( DATE_W3C ) ),
			esc_html( get_the_date() )
		);
		echo '<span class="posted-on">';
		printf(
			/* translators: %s: Publish date. */
			esc_html_x( 'Posted on %s', 'post date', 'nesiapress' ),
			'<a href="' . esc_url( get_permalink() ) . '" rel="bookmark">' . $time_string . '</a>'
		);
		echo '</span>';
	}
}

if ( ! function_exists( 'nesiapress_posted_by' ) ) :
	/**
	 * Prints HTML with meta information for the current author.
	 * 
	 * @since 1.0.0
	 */
	function nesiapress_posted_by() {
		$byline = sprintf(
			/* translators: %s: post author. */
			esc_html_x( 'by %s', 'post author', 'nesiapress' ),
			'<span class="author vcard"><a class="url fn n" href="' . esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) . '">' . esc_html( get_the_author() ) . '</a></span>'
		);

		echo '<span class="byline"> ' . $byline . '</span>'; // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped

	}
endif;

if ( ! function_exists( 'nesiapress_readmore' ) ) :
	/**
	 * Filter the "read more" excerpt string link to the post.
	 *
	 * @param string $more "Read more" excerpt string.
	 * @return string (Maybe) modified "read more" excerpt string.
	 * 
	 * @since 1.0.0
	 */
    function nesiapress_readmore($more) {
        global $post;
    return
			/* translators: %s: Read more. */
        '<span class="read-more">
		  		<a href="'. get_permalink( $post->ID ) . '" title="'. __( 'Read ', 'nesiapress' ) . esc_attr( get_the_title( $post->ID ) ).'">'. __( 'Read more <i class="fas fa-fw fa-arrow-alt-circle-right"></i>', 'nesiapress' ) .'</a>
        </span>';
    }

    add_filter('excerpt_more', 'nesiapress_readmore');
endif;

if ( ! function_exists( 'nesiapress_posts_pagination' ) ) :
	/**
	 * Prints HTML with meta information for the posts pagination
	 *
	 * @since 1.0.0
	 */
	function nesiapress_posts_pagination() {
		the_posts_pagination(
			array(
				'prev_text' => sprintf(
					'%s <span class="nav-prev-text">%s</span>',
					'<i class="fas fa-fw fa-chevron-left"></i>',
					__( '<span class="nav-short">Prev</span>', 'nesiapress' )
				),
				'next_text' => sprintf(
					'<span class="nav-next-text">%s</span> %s',
					__( '<span class="nav-short">Next</span>', 'nesiapress' ),
					'<i class="fas fa-fw fa-chevron-right"></i>'
				),
			)
		);
	}
endif;

if ( ! function_exists( 'nesiapress_entry_footer' ) ) :
	/**
	 * Prints HTML with meta information for the categories, tags and comments.
	 * 
	 * @since 1.0.0
	 */
	function nesiapress_entry_footer() {
		// Hide category and tag text for pages.
		if ( 'post' === get_post_type() ) {
			/* translators: used between list items, there is a space after the comma */
			$categories_list = get_the_category_list( esc_html__( ', ', 'nesiapress' ) );
			if ( $categories_list ) {
				/* translators: 1: list of categories. */
				printf( '<span class="cat-links"><i class="fas fa-fw fa-folder"></i>' . esc_html__( '%1$s', 'nesiapress' ) . '</span>', $categories_list );
			}

			/* translators: used between list items, there is a space after the comma */
			$tags_list = get_the_tag_list( '', esc_html_x( ', ', 'list item separator', 'nesiapress' ) );
			if ( $tags_list ) {
				/* translators: 1: list of tags. */
				printf( '<span class="tags-links"><i class="fas fa-fw fa-tag"></i>' . esc_html__( '%1$s', 'nesiapress' ) . '</span>', $tags_list );
			}
		}

		if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) {
			echo '<span class="comments-link"><i class="fas fa-fw fa-comment"></i>';
			comments_popup_link(
				sprintf(
					wp_kses(
						/* translators: %s: post title */
						__( 'Leave a Comment', 'nesiapress' ),
						array(
							'span' => array(
								'class' => array(),
							),
						)
					),
					wp_kses_post( get_the_title() )
				)
			);
			echo '</span>';
		}

		edit_post_link(
			sprintf(
				wp_kses(
					/* translators: %s: Name of current post. Only visible to screen readers */
					__( 'Edit', 'nesiapress' ),
					array(
						'span' => array(
							'class' => array(),
						),
					)
				),
				wp_kses_post( get_the_title() )
			),
			'<span class="edit-link"><i class="fas fa-fw fa-pen-square"></i>',
			'</span>'
		);
	}
endif;

if ( ! function_exists( 'nesiapress_post_thumbnail' ) ) :
	/**
	 * Displays an optional post thumbnail.
	 *
	 * Wraps the post thumbnail in an anchor element on index views, or a div
	 * element when on single views.
	 * 
	 * @since 1.0.0
	 */
	function nesiapress_post_thumbnail() {
		if ( post_password_required() || is_attachment() || ! has_post_thumbnail() ) {
			return;
		}

		if ( is_singular() ) :
			?>

			<div class="post-thumbnail">
				<?php the_post_thumbnail(); ?>
			</div><!-- .post-thumbnail -->

		<?php else : ?>

			<a class="post-thumbnail" href="<?php the_permalink(); ?>" aria-hidden="true" tabindex="-1">
			<?php
				the_post_thumbnail(
					'post-thumbnail',
					array(
						'alt' => the_title_attribute(
							array(
								'echo' => false,
							)
						),
					)
				);
			?>
			</a>

			<?php
		endif; // End is_singular().
	}
endif;

if ( ! function_exists( 'wp_body_open' ) ) :
	/**
	 * Shim for sites older than 5.2.
	 *
	 * @link https://core.trac.wordpress.org/ticket/12563
	 * 
	 * @since 1.0.0
	 */
	function wp_body_open() {
		do_action( 'wp_body_open' );
	}
endif;
